/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.simpleworkflow.model;

import java.io.Serializable;

/**
 * <p>
 * Provides details of the <code>WorkflowExecutionCompleted</code> event.
 * </p>
 */
public class WorkflowExecutionCompletedEventAttributes implements Serializable,
        Cloneable {

    /**
     * <p>
     * The result produced by the workflow execution upon successful completion.
     * </p>
     */
    private String result;
    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision task that resulted in the
     * <code>CompleteWorkflowExecution</code> decision to complete this
     * execution. This information can be useful for diagnosing problems by
     * tracing back the chain of events leading up to this event.
     * </p>
     */
    private Long decisionTaskCompletedEventId;

    /**
     * <p>
     * The result produced by the workflow execution upon successful completion.
     * </p>
     * 
     * @param result
     *        The result produced by the workflow execution upon successful
     *        completion.
     */

    public void setResult(String result) {
        this.result = result;
    }

    /**
     * <p>
     * The result produced by the workflow execution upon successful completion.
     * </p>
     * 
     * @return The result produced by the workflow execution upon successful
     *         completion.
     */

    public String getResult() {
        return this.result;
    }

    /**
     * <p>
     * The result produced by the workflow execution upon successful completion.
     * </p>
     * 
     * @param result
     *        The result produced by the workflow execution upon successful
     *        completion.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public WorkflowExecutionCompletedEventAttributes withResult(String result) {
        setResult(result);
        return this;
    }

    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision task that resulted in the
     * <code>CompleteWorkflowExecution</code> decision to complete this
     * execution. This information can be useful for diagnosing problems by
     * tracing back the chain of events leading up to this event.
     * </p>
     * 
     * @param decisionTaskCompletedEventId
     *        The ID of the <code>DecisionTaskCompleted</code> event
     *        corresponding to the decision task that resulted in the
     *        <code>CompleteWorkflowExecution</code> decision to complete this
     *        execution. This information can be useful for diagnosing problems
     *        by tracing back the chain of events leading up to this event.
     */

    public void setDecisionTaskCompletedEventId(
            Long decisionTaskCompletedEventId) {
        this.decisionTaskCompletedEventId = decisionTaskCompletedEventId;
    }

    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision task that resulted in the
     * <code>CompleteWorkflowExecution</code> decision to complete this
     * execution. This information can be useful for diagnosing problems by
     * tracing back the chain of events leading up to this event.
     * </p>
     * 
     * @return The ID of the <code>DecisionTaskCompleted</code> event
     *         corresponding to the decision task that resulted in the
     *         <code>CompleteWorkflowExecution</code> decision to complete this
     *         execution. This information can be useful for diagnosing problems
     *         by tracing back the chain of events leading up to this event.
     */

    public Long getDecisionTaskCompletedEventId() {
        return this.decisionTaskCompletedEventId;
    }

    /**
     * <p>
     * The ID of the <code>DecisionTaskCompleted</code> event corresponding to
     * the decision task that resulted in the
     * <code>CompleteWorkflowExecution</code> decision to complete this
     * execution. This information can be useful for diagnosing problems by
     * tracing back the chain of events leading up to this event.
     * </p>
     * 
     * @param decisionTaskCompletedEventId
     *        The ID of the <code>DecisionTaskCompleted</code> event
     *        corresponding to the decision task that resulted in the
     *        <code>CompleteWorkflowExecution</code> decision to complete this
     *        execution. This information can be useful for diagnosing problems
     *        by tracing back the chain of events leading up to this event.
     * @return Returns a reference to this object so that method calls can be
     *         chained together.
     */

    public WorkflowExecutionCompletedEventAttributes withDecisionTaskCompletedEventId(
            Long decisionTaskCompletedEventId) {
        setDecisionTaskCompletedEventId(decisionTaskCompletedEventId);
        return this;
    }

    /**
     * Returns a string representation of this object; useful for testing and
     * debugging.
     *
     * @return A string representation of this object.
     *
     * @see java.lang.Object#toString()
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("{");
        if (getResult() != null)
            sb.append("Result: " + getResult() + ",");
        if (getDecisionTaskCompletedEventId() != null)
            sb.append("DecisionTaskCompletedEventId: "
                    + getDecisionTaskCompletedEventId());
        sb.append("}");
        return sb.toString();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj)
            return true;
        if (obj == null)
            return false;

        if (obj instanceof WorkflowExecutionCompletedEventAttributes == false)
            return false;
        WorkflowExecutionCompletedEventAttributes other = (WorkflowExecutionCompletedEventAttributes) obj;
        if (other.getResult() == null ^ this.getResult() == null)
            return false;
        if (other.getResult() != null
                && other.getResult().equals(this.getResult()) == false)
            return false;
        if (other.getDecisionTaskCompletedEventId() == null
                ^ this.getDecisionTaskCompletedEventId() == null)
            return false;
        if (other.getDecisionTaskCompletedEventId() != null
                && other.getDecisionTaskCompletedEventId().equals(
                        this.getDecisionTaskCompletedEventId()) == false)
            return false;
        return true;
    }

    @Override
    public int hashCode() {
        final int prime = 31;
        int hashCode = 1;

        hashCode = prime * hashCode
                + ((getResult() == null) ? 0 : getResult().hashCode());
        hashCode = prime
                * hashCode
                + ((getDecisionTaskCompletedEventId() == null) ? 0
                        : getDecisionTaskCompletedEventId().hashCode());
        return hashCode;
    }

    @Override
    public WorkflowExecutionCompletedEventAttributes clone() {
        try {
            return (WorkflowExecutionCompletedEventAttributes) super.clone();
        } catch (CloneNotSupportedException e) {
            throw new IllegalStateException(
                    "Got a CloneNotSupportedException from Object.clone() "
                            + "even though we're Cloneable!", e);
        }
    }
}
